<%-- $Id: edit_tag.jsp 7604 2019-02-25 12:19:50Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------


	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.AnnotationType"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.Tag"
	import="net.sf.basedb.core.ItemSubtype"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.Include"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.edit.EditUtil"
	import="net.sf.basedb.clients.web.extensions.tabcontrol.TabAction"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="net.sf.basedb.util.Values"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%
final Item itemType = Item.TAG;
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl();
try
{
	String title = null;
	Tag tag = null;
	boolean readCurrentTagType = true;
	int currentTagTypeId = 0;

	if (itemId == 0)
	{
		title = "Create tag";
		cc.removeObject("item");
		currentTagTypeId = Values.getInt(request.getParameter("tagtype_id"));
		if (currentTagTypeId == 0) 
		{
			int recentTagTypeId = Values.getInt(cc.getRecent(Item.ITEMSUBTYPE.name(), 0));
			currentTagTypeId = Values.getInt(cc.getPropertyValue("itemSubtype"), recentTagTypeId);
		}
	}
	else
	{
		tag = Tag.getById(dc, itemId);
		tag.checkPermission(Permission.WRITE);
		cc.setObject("item", tag);
		title = "Edit tag -- " + HTML.encodeTags(tag.getName());
		try
		{
			ItemSubtype tagType = tag.getItemSubtype();
			if (tagType != null) currentTagTypeId = tagType.getId();
		}
		catch (PermissionDeniedException ex)
		{
			readCurrentTagType = false;
		}
	}
	
	// Query to retrieve tag types
	final ItemQuery<ItemSubtype> tagTypeQuery = ItemSubtype.getQuery(itemType);
	tagTypeQuery.include(Include.ALL);
	tagTypeQuery.order(Orders.asc(Hql.property("name")));
	
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.item(itemType), tag);
	ExtensionsInvoker<TabAction> invoker = EditUtil.useEditExtensions(jspContext);
	%>
	<base:page type="popup" title="<%=title%>" id="edit-page">
	<base:head scripts="tabcontrol-2.js,~tags.js" styles="tabcontrol.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		<h1><%=title%> <base:help tabcontrol="settings"/></h1>
		<form action="index.jsp?ID=<%=ID%>" method="post" name="tag">
		<input type="hidden" name="cmd" value="UpdateItem">

		<t:tabcontrol id="settings" 
			subclass="content dialogtabcontrol"
			position="bottom"  remember="<%=tag != null%>"
			extensions="<%=invoker%>">
		<t:tab id="info" title="Tag" helpid="tag.edit">
			<table class="fullform input100 smaller">
			<tr>
				<th>Name</th>
				<td><input class="text required auto-init" data-auto-init="<%=tag == null ? "focus-select" : "focus" %>"
					type="text" name="name" 
					value="<%=HTML.encodeTags(tag == null ? Values.getString(cc.getPropertyValue("name"), "New tag") : tag.getName())%>" 
					maxlength="<%=Tag.MAX_NAME_LENGTH%>"></td>
				<td></td>
			</tr>
			<tr>
				<th>Type</th>
				<td>
					<select name="tagtype_id" 
						<%=!readCurrentTagType ? "disabled readonly class=\"disabled\"" : "class=\"required\""%>>
					<%
					if (!readCurrentTagType)
					{
						%>
						<option value="-1">- denied -
						<%
					}
					else
					{
						for (ItemSubtype tagType : tagTypeQuery.list(dc))
						{
							int id = tagType.getId();
							if (id != currentTagTypeId && tagType.isRemoved()) continue;
							%>
							<option value="<%=id == currentTagTypeId && tag != null ? -id : id%>" 
								<%=id == currentTagTypeId ? "selected" : ""%>
								><%=HTML.encodeTags(tagType.getName())%>
							<%
						}
					}
					%>
					</select>
				</td>
				<td></td>
			</tr>
			<tr class="dynamic">
				<th>Description</th>
				<td>
					<textarea class="text" rows="6" name="description" id="description"
						><%=HTML.encodeTags(tag == null ? cc.getPropertyValue("description") : tag.getDescription())%></textarea>
				</td>
				<td style="width: 20px;">
					<base:zoom textarea="description" title="Description" />
				</td>
			</tr>
			</table>
		</t:tab>
		<t:tab id="annotations" title="Annotations" helpid="annotations.edit">
			<jsp:include page="../../common/annotations/annotate_frameset.jsp">
				<jsp:param name="item_type" value="<%=itemType.name()%>" />
				<jsp:param name="item_id" value="<%=itemId%>" />
				<jsp:param name="ID" value="<%=ID%>" />
			</jsp:include>
		</t:tab>
		</t:tabcontrol>
		</form>
		
		<div class="legend">
			<base:icon image="required.png" />= required information
		</div>

		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Save" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
