<%-- $Id: index.jsp 7603 2019-02-22 12:50:40Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.BasicItem"
	import="net.sf.basedb.core.Project"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Presets"
	import="net.sf.basedb.core.Presets.Preset"
	import="net.sf.basedb.util.overview.GenericOverview"
	import="net.sf.basedb.util.overview.Node"
	import="net.sf.basedb.util.overview.Validator"
	import="net.sf.basedb.util.overview.ValidationOptions"
	import="net.sf.basedb.util.overview.Severity"
	import="net.sf.basedb.util.overview.extensions.ValidationRuleAction"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.WebException"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.overview.OverviewUtil"
	import="net.sf.basedb.clients.web.util.HTML"
	import="java.util.Map"
	import="java.util.List"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final String cmd = request.getParameter("cmd");
final String root = request.getContextPath()+"/";

String forward = null;
String redirect = null;
String message = null;
DbControl dc = null;
try
{
	if (cmd == null || "Overview".equals(cmd))
	{
		// Display the overview page
		final Item itemType = Item.valueOf(request.getParameter("item_type"));
		final int itemId = Values.getInt(request.getParameter("item_id"));
		final boolean forceNew = Values.getBoolean(request.getParameter("forceNew"));

		dc = sc.newDbControl();
		BasicItem item = itemType.getById(dc, itemId);
		Project project = sc.getActiveProjectId() == 0 ? 
				null : Project.getById(dc, sc.getActiveProjectId());
		GenericOverview overview = forceNew ? 
			OverviewUtil.getNewOverview(dc, item, project) : OverviewUtil.getNewOrCurrentOverview(dc, item, project);
		overview.getNodeValidatorFactory().setDisabled(true);
		overview.expand(dc, overview.getRootNode(), false);
		dc.close();
		redirect = "frameset.jsp?ID="+ID+"&show_failures="+false;
	}
	else if ("Validate".equals(cmd))
	{
		final Item itemType = Item.valueOf(request.getParameter("item_type"));
		final int itemId = Values.getInt(request.getParameter("item_id"));
		dc = sc.newDbControl();
		BasicItem item = itemType.getById(dc, itemId);
		Project project = sc.getActiveProjectId() == 0 ? 
				null : Project.getById(dc, sc.getActiveProjectId());
		GenericOverview overview = OverviewUtil.getNewOverview(dc, item, project);
		overview.expand(dc, overview.getRootNode(), true);
		overview.updateFailureCountOnNodes();
		dc.close();
		redirect = "frameset.jsp?ID="+ID+"&item_type="+itemType.name()+"&item_id="+itemId+"&show_failures="+true;
	}
	else if ("SaveValidationOptions".equals(cmd))
	{
		dc = sc.newDbControl();
		GenericOverview overview = OverviewUtil.getCurrentOverview(sc);
		ValidationOptions options = overview.getValidationOptions();
		Presets presets = OverviewUtil.getValidationPresets(sc);
		for (Map.Entry<String, List<ValidationRuleAction>> entry : OverviewUtil.getAllRules(dc, overview).entrySet())
		{
			for (ValidationRuleAction validator : entry.getValue())
			{
				options.setSeverity(validator, Severity.valueOf(request.getParameter(validator.getId())));
			}
		}
		options.setOption((ValidationRuleAction)Validator.NONMATCHING_SPOTCOUNT, "threshold", request.getParameter("threshold"));
		options.saveToPreset(presets.getDefault());
		OverviewUtil.saveValidationPresets(sc);
		overview.updateFailureCountOnNodes();
	}
	else if ("SaveAsPreset".equals(cmd))
	{
		dc = sc.newDbControl();
		GenericOverview overview = OverviewUtil.getCurrentOverview(sc);
		Presets presets = OverviewUtil.getValidationPresets(sc);
		String name = request.getParameter("presetName");
		Preset preset = presets.getPreset(name);
		for (Map.Entry<String, List<ValidationRuleAction>> entry : OverviewUtil.getAllRules(dc, overview).entrySet())
		{
			for (ValidationRuleAction validator : entry.getValue())
			{
				preset.setSetting(validator.getId(), request.getParameter(validator.getId()));
			}
		}
		preset.setSetting(Validator.NONMATCHING_SPOTCOUNT.getId() + "+threshold", 
				request.getParameter("threshold"));
		OverviewUtil.saveValidationPresets(sc);
		forward = "options.jsp";
	}
	else if ("RemovePreset".equals(cmd))
	{
		Presets presets = OverviewUtil.getValidationPresets(sc);
		String name = request.getParameter("presetName");
		presets.deletePreset(name);
		OverviewUtil.saveValidationPresets(sc);
		redirect = "options.jsp?ID=" + ID;
	}
	else
	{
		throw new WebException("popup", "Invalid command", "The command {1} is not recognised as a valid command.", cmd);
	}
}
finally
{
	if (dc != null) dc.close();
}

if (forward != null)
{
	sc.setSessionSetting("alert-message", message);
	pageContext.forward(forward);
}
else if (redirect != null)
{
	sc.setSessionSetting("alert-message", message);
	response.sendRedirect(redirect);
}
else if (message == null)
{
	response.sendRedirect(root + "common/close_popup.jsp?refresh_opener=1&wait=0");
}
else
{
	response.sendRedirect(root + "common/close_popup.jsp?refresh_opener=1&message="+HTML.urlEncode(message));
}
%>

