<%-- $Id: list_reporters.jsp 7604 2019-02-25 12:19:50Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Johan Enell, Jari Häkkinen, Nicklas Nordborg, Martin Svensson
	Copyright (C) 2007 Johan Enell, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Reporter"
	import="net.sf.basedb.core.ReporterType"
	import="net.sf.basedb.core.PluginDefinition"
	import="net.sf.basedb.core.data.ReporterData"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.ItemResultList"
	import="net.sf.basedb.core.DataQuery"
	import="net.sf.basedb.core.DataResultIterator"
	import="net.sf.basedb.core.ExtendedProperty"
	import="net.sf.basedb.core.ExtendedProperties"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.core.plugin.Plugin"
	import="net.sf.basedb.util.Enumeration"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.ModeInfo"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.renderer.PrefixSuffixRenderer"
	import="net.sf.basedb.clients.web.extensions.toolbar.ButtonAction" 
	import="net.sf.basedb.clients.web.extensions.toolbar.ToolbarUtil"
	import="net.sf.basedb.clients.web.extensions.list.ListColumnAction"
	import="net.sf.basedb.clients.web.extensions.list.ListColumnUtil"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.Date"
	import="java.util.Map"
	import="java.util.List"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%!
	private static final Item itemType = Item.REPORTER;
	private static final GuiContext guiContext = new GuiContext(itemType, GuiContext.Type.LIST);
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, Permission.DENIED, itemType);
final String ID = sc.getId();
final boolean createPermission = sc.hasPermission(Permission.CREATE, itemType);
final boolean writePermission = sc.hasPermission(Permission.WRITE, itemType);
final boolean deletePermission = sc.hasPermission(Permission.DELETE, itemType);

final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);

final ModeInfo mode = ModeInfo.get(request.getParameter("mode"));
final String callback = request.getParameter("callback");
final String title = mode.generateTitle("reporter", "reporters");
final DbControl dc = sc.newDbControl();
DataResultIterator<ReporterData> reporters = null;
ItemResultList<ReporterType> reporterTypes = null;
try
{
	final DataQuery<ReporterData> query = Reporter.getQuery();
	cc.configureQuery(dc, query, true);

	Map<Plugin.MainType, Integer> pluginCount = PluginDefinition.countPlugins(dc, guiContext);
	final ItemQuery<ReporterType> typeQuery = ReporterType.getQuery();
	typeQuery.order(Orders.asc(Hql.property("name")));
	typeQuery.setCacheResult(true);
	List<ExtendedProperty> reporterProperties = ExtendedProperties.getProperties("ReporterData");
	try
	{
		reporters = query.iterate(dc);
	}
	catch (Throwable t)
	{
		cc.setMessage(t.getMessage());
		t.printStackTrace();
	}
	int numListed = 0;
	Formatter<Date> timeFormatter = FormatterFactory.getDateTimeFormatter(sc);
	Formatter<Date> dateFormatter = FormatterFactory.getDateFormatter(sc);
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, guiContext, null);
	ExtensionsInvoker<ButtonAction> invoker = ToolbarUtil.useExtensions(jspContext);
	ExtensionsInvoker<ListColumnAction<ReporterData,?>> columnsInvoker = ListColumnUtil.useExtensions(jspContext);
	%>
	<base:page title="<%=title==null ? "Reporters" : title%>" type="<%=mode.getPageType()%>" id="list-page">
	<base:head scripts="table.js,~reporters.js" styles="table.css,toolbar.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	
	<base:body>
	<h1><%=title==null ? "Reporters" : title%></h1>
	<div class="content">
		<tbl:table 
			id="reporters" 
			columns="<%=cc.getSetting("columns")%>"
			sortby="<%=cc.getSortProperty()%>" 
			direction="<%=cc.getSortDirection()%>"
			action="index.jsp"
			sc="<%=sc%>"
			item="<%=itemType%>"
			filterrows="<%=cc.getFilterRows() %>"
			subclass="fulltable"
			>
			<tbl:hidden 
				name="mode" 
				value="<%=mode.getName()%>" 
			/>
			<tbl:hidden 
				name="callback" 
				value="<%=callback%>" 
				skip="<%=callback == null%>" 
			/>
			<tbl:columndef 
				id="externalId"
				clazz="uniquecol"
				property="externalId"
				datatype="string"
				title="External ID"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="name"
				property="name"
				datatype="string"
				title="Name"
				sortable="true" 
				filterable="true"
				exportable="true"
				show="always" 
			/>
			<tbl:columndef 
				id="id"
				clazz="uniquecol"
				property="id"
				datatype="int"
				title="ID"
				sortable="true"
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="symbol"
				property="symbol"
				datatype="string"
				title="Gene symbol"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<tbl:columndef 
				id="description"
				property="description"
				datatype="string"
				title="Description" 
				sortable="true" 
				filterable="true" 
				exportable="true"
			/>
			<tbl:columndef
				id="reporterList"
				property="£reporterListScores"
				datatype="int"
				title="Reporter list"
				filterable="true"
				enumeration="<%=Base.getReporterListsEnum(dc)%>"
				multiple="false"
			/>
			<tbl:columndef 
				id="entryDate"
				property="entryDate"
				datatype="date"
				title="Registered"
				sortable="true" 
				filterable="true"
				exportable="true"
				formatter="<%=dateFormatter%>"
			/>
			<tbl:columndef 
				id="lastUpdate"
				property="lastUpdate"
				datatype="timestamp"
				title="Last update" 
				sortable="true" 
				filterable="true" 
				exportable="true"
				formatter="<%=timeFormatter%>"
			/>
			<tbl:columndef 
				id="lastSource"
				property="lastSource"
				datatype="string"
				title="Last source"
				sortable="true"
				filterable="true"
				exportable="true"
			/>
			<%
			Enumeration<String, String> types = new Enumeration<String, String>();
			reporterTypes = typeQuery.list(dc);
			types.add("", "- none -");
			for (ReporterType rt : reporterTypes)
			{
				types.add(Integer.toString(rt.getId()), HTML.encodeTags(rt.getName()));
			}
			%>
			<tbl:columndef 
				id="reporterType"
				property="reporterType"
				sortproperty="reporterType.name"
				exportproperty="reporterType.name:string"
				datatype="int"
				enumeration="<%=types%>"
				title="Type"
				sortable="true" 
				filterable="true"
				exportable="true"
			/>
			<%
			if (reporterProperties != null)
			{
				for (ExtendedProperty ep : reporterProperties)
				{
					String name = ep.getName();
					%>
					<tbl:columndef
						id="<%=name%>"
						property="<%=name%>"
						datatype="<%=ep.getType().getStringValue()%>"
						title="<%=HTML.encodeTags(ep.getTitle())%>"
						sortable="true"
						filterable="true"
						exportable="true"
						formatter="<%=FormatterFactory.getExtendedPropertyFormatter(sc, ep)%>"
					/>
					<%
				}
			}
			%>
			<tbl:columndef 
				id="xt-columns" 
				extensions="<%=columnsInvoker%>" 
				jspcontext="<%=jspContext%>" 
			/>
		<div class="panelgroup bg-filled-50 bottomborder">
			<tbl:toolbar
				visible="<%=mode.hasToolbar()%>"
				subclass="bottomborder"
				>
				<tbl:button 
					id="btnNewItem"
					disabled="<%=!createPermission%>" 
					image="new.png" 
					title="New&hellip;" 
					tooltip="<%=createPermission ? "Create a new reporter" : "You do not have permission to create reporter"%>" 
				/>
				<tbl:button 
					id="btnDeleteItems"
					data-confirm="1"
					disabled="<%=!deletePermission%>" 
					image="delete.png" 
					title="Delete&hellip;" 
					tooltip="<%=deletePermission ? "Delete the selected items" : "You do not have permission to delete reporters" %>" 
				/>
				<tbl:button 
					id="btnColumns"
					image="columns.png" 
					title="Columns&hellip;" 
					tooltip="Show, hide and re-order columns" 
				/>
				<tbl:button
					id="btnNewReporterList"
					image="add.png"
					title="New reporter list&hellip;"
					tooltip="Create a new reporter list from matching reporters"
					visible="<%=sc.hasPermission(Permission.CREATE, Item.REPORTERLIST)%>"
				/>
				<tbl:button 
					id="btnImport"
					data-plugin-type="IMPORT"
					image="import.png" 
					title="Import&hellip;" 
					tooltip="Import data" 
					visible="<%=pluginCount.containsKey(Plugin.MainType.IMPORT)%>"
				/>
				<tbl:button 
					id="btnExport"
					data-plugin-type="EXPORT"
					image="export.png" 
					title="Export&hellip;" 
					tooltip="Export data" 
					visible="<%=pluginCount.containsKey(Plugin.MainType.EXPORT)%>"
				/>
				<tbl:button 
					id="btnRunPlugin"
					data-plugin-type="OTHER"
					image="runplugin.png" 
					title="Run plugin&hellip;" 
					tooltip="Run a plugin" 
					visible="<%=pluginCount.containsKey(Plugin.MainType.OTHER)%>"
				/>
				<ext:render extensions="<%=invoker%>" context="<%=jspContext%>" 
					wrapper="<%=new PrefixSuffixRenderer<ButtonAction>(jspContext, "<td>", "</td>") %>"/>
			</tbl:toolbar>
			<tbl:panel>
				<tbl:presetselector />
				<tbl:navigator
					page="<%=cc.getPage()%>" 
					rowsperpage="<%=cc.getRowsPerPage()%>" 
					totalrows="<%=reporters == null ? 0 : reporters.getTotalCount()%>" 
					visible="<%=mode.hasNavigator()%>"
				/>
			</tbl:panel>
		</div>
			<tbl:data>
				<tbl:headers>
					<tbl:headerrow>
						<tbl:header colspan="3" />
						<tbl:columnheaders />
					</tbl:headerrow>
					<%
					int numFilters = cc.getNumPropertyFilters();
					int numRows = cc.getFilterRows();
					for (int filterNo = 0; filterNo < numRows; filterNo++)
					{
						boolean lastRow = filterNo == numRows-1;
						%>
						<tbl:headerrow>
							<tbl:header subclass="index" />
							<tbl:header 
								subclass="check" 
								visible="<%=mode.hasCheck()%>"
								><base:icon 
									subclass="link table-check"
									image="check_uncheck.png" 
									tooltip="Toggle all (use CTRL, ALT or SHIFT to check/uncheck)" 
									visible="<%=lastRow%>"
								/></tbl:header>
							<tbl:header 
								subclass="check" 
								visible="<%=mode.hasRadio()%>"
								/>
							<tbl:header 
								subclass="icons" 
								visible="<%=mode.hasIcons()%>"
								>
								<base:icon
									subclass="link table-filter-row-action"
									image="add.png"
									tooltip="Add extra filter row"
									visible="<%=lastRow%>"
								/><base:icon
									subclass="link table-filter-row-action"
									image="remove.png"
									tooltip="Remove this filter row"
									visible="<%=numRows > 1 || numFilters > 0 %>"
									data-remove-row="<%=filterNo%>"
								/>
							</tbl:header>
							<tbl:propertyfilter row="<%=filterNo%>" />
						</tbl:headerrow>
						<%
					}
					%>
				</tbl:headers>
				<tbl:rows>
					<%
					if (cc.getMessage() != null)
					{
						%>
						<tbl:panel subclass="bg-filled-50">
							<div class="messagecontainer error"><%=cc.getMessage()%></div>
						</tbl:panel>
						<%
						cc.setMessage(null);
					}
					int index = cc.getPage()*cc.getRowsPerPage();
					int selectedItemId = cc.getId();
					if (reporters != null)
					{
						while (reporters.hasNext())
						{
							ReporterData item = reporters.next();
							int itemId = item.getId();
							String name = HTML.encodeTags(item.getName());
							String tooltip = mode.isSelectionMode() ?
									"Select this item" : "View this item" + (writePermission ? " (use CTRL, ALT or SHIFT to edit)" : "");
							index++;
							numListed++;
							%>
							<tbl:row>
								<tbl:header 
									clazz="index"
									><%=index%></tbl:header>
								<tbl:header 
									clazz="check" 
									visible="<%=mode.hasCheck()%>"
									><input 
										type="checkbox" 
										name="<%=itemId%>" 
										value="<%=itemId%>" 
										title="<%=name%>" 
										<%=cc.getSelected().contains(itemId) ? "checked" : ""%> 
									></tbl:header>
								<tbl:header 
									clazz="check" 
									visible="<%=mode.hasRadio()%>"
									><input 
										type="radio" 
										name="item_id" 
										value="<%=itemId%>" 
										title="<%=name%>" 
										<%=selectedItemId == itemId ? "checked" : ""%>
									></tbl:header>
								<tbl:header 
									clazz="icons" 
									visible="<%=mode.hasIcons()%>"
									>&nbsp;</tbl:header>
								<tbl:cell column="name"><div
									class="link table-item"
									data-item-id="<%=itemId%>"
									data-no-edit="<%=writePermission ? 0 : 1 %>" 
									tabindex="0"
									title="<%=tooltip%>"><%=name%></div></tbl:cell>
								<tbl:cell column="id"><%=item.getId()%></tbl:cell>
								<tbl:cell column="externalId"><%=HTML.encodeTags(item.getExternalId())%></tbl:cell>
								<tbl:cell column="symbol"><%=HTML.encodeTags(item.getSymbol())%></tbl:cell>
								<tbl:cell column="description"><%=HTML.encodeTags(item.getDescription())%></tbl:cell>
								<tbl:cell column="entryDate" value="<%=item.getEntryDate()%>" />
								<tbl:cell column="lastUpdate" value="<%=item.getLastUpdate()%>" />
								<tbl:cell column="lastSource"><%=HTML.encodeTags(item.getLastSource())%></tbl:cell>
								<tbl:cell column="reporterType"
									><base:propertyvalue 
										dbcontrol="<%=dc%>" 
										item="<%=item%>" 
										property="reporterType"
										enableEditLink="<%=mode.hasEditLink()%>" 
										enablePropertyLink="<%=mode.hasPropertyLink()%>"
									/></tbl:cell>
								<%
								if (reporterProperties != null)
								{
									for (ExtendedProperty ep : reporterProperties)
									{
										name = ep.getName();
										%>
										<tbl:cell column="<%=name%>"><tbl:cellvalue value="<%=item.getExtended(name)%>" /></tbl:cell>
										<%
									}
								}
								%>
								<tbl:xt-cells dc="<%=dc%>" item="<%=item%>">
									<tbl:cell column="xt-columns" />
								</tbl:xt-cells>
							</tbl:row>
							<%
						}
					}
					if (numListed == 0)
					{
						%>
						<tbl:panel subclass="bg-filled-50">
							<div class="messagecontainer note">
							<%=reporters == null || reporters.getTotalCount() == 0 ? "No reporters were found" : "No reporters on this page. Please select another page!" %>
							</div>
						</tbl:panel>
						<%
					}
					%>
				</tbl:rows>
			</tbl:data>
		</tbl:table>
		
		</div>
		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnOk" title="Ok" visible="<%=mode.hasOkButton()%>" />
			<base:button id="close" title="Cancel" visible="<%=mode.hasCancelButton()%>" />
			<base:button id="close" title="Close" visible="<%=mode.hasCloseButton()%>" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (reporters != null) reporters.close();
	if (dc != null) dc.close();
}
%>
